summaryrefslogtreecommitdiff
path: root/pkg
diff options
context:
space:
mode:
Diffstat (limited to 'pkg')
-rw-r--r--pkg/api/handlers/generic/images.go2
-rw-r--r--pkg/api/handlers/libpod/pods.go4
-rw-r--r--pkg/api/tags.yaml2
-rw-r--r--pkg/bindings/test/images_test.go2
-rw-r--r--pkg/bindings/test/pods_test.go4
-rw-r--r--pkg/spec/security.go6
6 files changed, 10 insertions, 10 deletions
diff --git a/pkg/api/handlers/generic/images.go b/pkg/api/handlers/generic/images.go
index 3da5807ec..078896834 100644
--- a/pkg/api/handlers/generic/images.go
+++ b/pkg/api/handlers/generic/images.go
@@ -90,7 +90,7 @@ func PruneImages(w http.ResponseWriter, r *http.Request) {
})
}
- //FIXME/TODO to do this exacty correct, pruneimages needs to return idrs and space-reclaimed, then we are golden
+ //FIXME/TODO to do this exactly correct, pruneimages needs to return idrs and space-reclaimed, then we are golden
ipr := types.ImagesPruneReport{
ImagesDeleted: idr,
SpaceReclaimed: 1, // TODO we cannot supply this right now
diff --git a/pkg/api/handlers/libpod/pods.go b/pkg/api/handlers/libpod/pods.go
index e8dc5bde2..ee697b6b7 100644
--- a/pkg/api/handlers/libpod/pods.go
+++ b/pkg/api/handlers/libpod/pods.go
@@ -181,7 +181,7 @@ func PodStop(w http.ResponseWriter, r *http.Request) {
}
// TODO we need to implement a pod.State/Status in libpod internal so libpod api
- // users dont have to run through all containers.
+ // users don't have to run through all containers.
podContainers, err := pod.AllContainers()
if err != nil {
utils.Error(w, "Something went wrong", http.StatusInternalServerError, err)
@@ -227,7 +227,7 @@ func PodStart(w http.ResponseWriter, r *http.Request) {
}
// TODO we need to implement a pod.State/Status in libpod internal so libpod api
- // users dont have to run through all containers.
+ // users don't have to run through all containers.
podContainers, err := pod.AllContainers()
if err != nil {
utils.Error(w, "Something went wrong", http.StatusInternalServerError, err)
diff --git a/pkg/api/tags.yaml b/pkg/api/tags.yaml
index 3bf2bb64f..571f49e44 100644
--- a/pkg/api/tags.yaml
+++ b/pkg/api/tags.yaml
@@ -18,4 +18,4 @@ tags:
- name: images (compat)
description: Actions related to images for the compatibility endpoints
- name: system (compat)
- description: Actions related to Podman and compatiblity engines
+ description: Actions related to Podman and compatibility engines
diff --git a/pkg/bindings/test/images_test.go b/pkg/bindings/test/images_test.go
index 0baf0cb20..17b3b254a 100644
--- a/pkg/bindings/test/images_test.go
+++ b/pkg/bindings/test/images_test.go
@@ -140,7 +140,7 @@ var _ = Describe("Podman images", func() {
code, _ := bindings.CheckResponseCode(err)
Expect(code).To(BeNumerically("==", http.StatusNotFound))
- // Validates if the image is tagged sucessfully.
+ // Validates if the image is tagged successfully.
err = images.Tag(bt.conn, alpine.shortName, "demo", alpine.shortName)
Expect(err).To(BeNil())
diff --git a/pkg/bindings/test/pods_test.go b/pkg/bindings/test/pods_test.go
index a0099753b..7e29265b7 100644
--- a/pkg/bindings/test/pods_test.go
+++ b/pkg/bindings/test/pods_test.go
@@ -115,7 +115,7 @@ var _ = Describe("Podman pods", func() {
Expect(err).To(BeNil())
// Binding needs to be modified to inspect the pod state.
- // Since we dont have a pod state we inspect the states of the containers within the pod.
+ // Since we don't have a pod state we inspect the states of the containers within the pod.
// Pause a valid container
err = pods.Pause(bt.conn, newpod)
Expect(err).To(BeNil())
@@ -195,7 +195,7 @@ var _ = Describe("Podman pods", func() {
}
})
- // Test to validate all the pods in the stopped/exited state are pruned sucessfully.
+ // Test to validate all the pods in the stopped/exited state are pruned successfully.
It("prune pod", func() {
// Add a new pod
var newpod2 string = "newpod2"
diff --git a/pkg/spec/security.go b/pkg/spec/security.go
index ca025eb3e..0f8d36f00 100644
--- a/pkg/spec/security.go
+++ b/pkg/spec/security.go
@@ -128,10 +128,10 @@ func (c *SecurityConfig) ConfigureGenerator(g *generate.Generator, user *UserCon
privCapRequired := []string{}
if !c.Privileged && len(c.CapRequired) > 0 {
// Pass CapRequired in CapAdd field to normalize capabilties names
capRequired, err := capabilities.MergeCapabilities(nil, c.CapRequired, nil)
if err != nil {
- logrus.Errorf("capabilties requested by user or image are not valid: %q", strings.Join(c.CapRequired, ","))
+ logrus.Errorf("capabilities requested by user or image are not valid: %q", strings.Join(c.CapRequired, ","))
} else {
// Verify all capRequiered are in the defaultCapList
for _, cap := range capRequired {
@@ -143,7 +143,7 @@ func (c *SecurityConfig) ConfigureGenerator(g *generate.Generator, user *UserCon
if len(privCapRequired) == 0 {
defaultCaplist = capRequired
} else {
- logrus.Errorf("capabilties requested by user or image are not allowed by default: %q", strings.Join(privCapRequired, ","))
+ logrus.Errorf("capabilities requested by user or image are not allowed by default: %q", strings.Join(privCapRequired, ","))
}
}
configSpec.Process.Capabilities.Bounding = defaultCaplist
@@ -128,10 +128,10 @@ func (c *SecurityConfig) ConfigureGenerator(g *generate.Generator, user *UserCon
privCapRequired := []string{}
if !c.Privileged && len(c.CapRequired) > 0 {
- // Pass CapRequired in CapAdd field to normalize capabilties names
+ // Pass CapRequired in CapAdd field to normalize capabilities names
capRequired, err := capabilities.MergeCapabilities(nil, c.CapRequired, nil)
if err != nil {